import Mock, { Random } from 'mockjs';

// 自定义函数：生成在指定日期范围内的随机日期
function getRandomDate(start, end) {
  const startTime = new Date(start).getTime();
  const endTime = new Date(end).getTime();
  const randomTime = new Date(startTime + Math.random() * (endTime - startTime));
  return randomTime.toISOString().slice(0, 19).replace('T', ' '); // 格式化为 "yyyy-MM-dd HH:mm:ss"
}
const startDate = '2023-01-01 00:00:00'; // 起始日期
const endDate = '2024-12-31 23:59:59'; // 结束日期

export const fileData = (num) => {
  return Mock.mock({
    [`list|${num}`]: [
      // 根据 num 动态生成用户数量
      {
        'c1|+1': 1,
        'c2|18-60': 1,
        c3: '@cname',
        c4: '@pick(["男", "女"])',
        'c5|170-190': 1,
        c6: function () {
          return getRandomDate(startDate, endDate);
        },
        c7: function () {
          return getRandomDate(startDate, endDate);
        },
        c8: '@cname',
        c9: '@cname',
        c10: '@sentence(5, 10)',
      },
    ],
  }).list;
};
export const dataSourceData = [
  {
    businessId: 1,
    source: 'bm_datasource',
    target: 'bm_datasource',
    areaConfig: null,
    clearConfig: null,
  },
];
export const dataSourceFieldData = [
  {
    businessId: 1,
    sourceField: 'target field',
    targetField: 'target field',
    fieldRemark: null,
  },
  {
    businessId: 2,
    sourceField: 'source field',
    targetField: 'source field',
    fieldRemark: null,
  },
  {
    businessId: 3,
    sourceField: 'field comment',
    targetField: 'field comment',
    fieldRemark: null,
  },
];
export const cardRuleList = [
  {
    title: '【全局】新增字段规则',
    type: 'newFieldRule',
    description: '为源端所有数据表都新增一个字段，例如为每张表增加一个入库时间列',
  },
  {
    title: '数据转换规则',
    type: 'dataTransformationRule',
    description: '根据业务需求，对源端单张数据表的单个字段进行数据转换操作',
  },
  {
    title: '数据过滤规则',
    type: 'dataFilterRule',
    description: '根据业务需求，对源端单张数据表的数据进行过滤操作',
  },
];
export const mappingRuleConfigurationTableList = [
  {
    businessId: 1,
    ruleName: '[全局] 新增字段规则',
    ruleContent: '新增字段名称:a, 字段类型:string, 字段表达式:asd',
  },
  {
    businessId: 2,
    ruleName: '数据转换规则',
    ruleContent: '数据表: table1, 已有字段: field1, 转换规则: 配置规则',
  },
  {
    businessId: 3,
    ruleName: '数据过滤规则',
    ruleContent: "自定义规则:field1 != 'axxc'",
  },
];
export const runOptionsData: any[] = [
  {
    name: 'tdt.job.cleaning',
    type: '服务参数',
    data: 'true',
  },
  {
    name: 'tdt.jdbc.mapper.size',
    type: '服务参数',
    data: '1024',
  },
  {
    name: 'tdt.job.mapper.count',
    type: '服务参数',
    data: 'true',
  },
  {
    name: 'tdt.strict.mode',
    type: '服务参数',
    data: 'false',
  },
];
export const exFunctionOptions = [
  {
    label: '变更字段名',
    value: '变更字段名',
  },
  {
    label: '变更字段数据类型',
    value: '变更字段数据类型',
  },
  {
    label: '添加新字段',
    value: '添加新字段',
  },
  {
    label: '删除字段',
    value: '删除字段',
  },
  {
    label: '重命名表',
    value: '重命名表',
  },
  {
    label: '创建索引',
    value: '创建索引',
  },
  {
    label: '删除索引',
    value: '删除索引',
  },
  {
    label: '添加主键',
    value: '添加主键',
  },
  {
    label: '移除主键',
    value: '移除主键',
  },
  {
    label: '添加外键约束',
    value: '添加外键约束',
  },
  {
    label: '移除外键约束',
    value: '移除外键约束',
  },
];
export const configTableData = [
  {
    key: '变更字段名',
    value: [
      {
        field: 'table_name',
        value: null,
      },
      {
        field: 'old_column_name',
        value: null,
      },
      {
        field: 'new_column_name',
        value: null,
      },
      {
        field: 'column_type',
        value: null,
      },
    ],
  },
  {
    key: '变更字段数据类型',
    value: [
      {
        field: 'table_name',
        value: null,
      },
      {
        field: 'column_name',
        value: null,
      },
      {
        field: 'new_column_type',
        value: null,
      },
    ],
  },
  {
    key: '添加新字段',
    value: [
      {
        field: 'table_name',
        value: null,
      },
      {
        field: 'new_column_name',
        value: null,
      },
      {
        field: 'column_type',
        value: null,
      },
      {
        field: 'default_value',
        value: null,
      },
    ],
  },
  {
    key: '删除字段',
    value: [
      {
        field: 'table_name',
        value: null,
      },
      {
        field: 'column_name',
        value: null,
      },
    ],
  },
  {
    key: '重命名表',
    value: [
      {
        field: 'old_table_name',
        value: null,
      },
      {
        field: 'new_table_name',
        value: null,
      },
    ],
  },
  {
    key: '创建索引',
    value: [
      {
        field: 'index_name',
        value: null,
      },
      {
        field: 'table_name',
        value: null,
      },
      {
        field: 'column_name',
        value: null,
      },
    ],
  },
  {
    key: '删除索引',
    value: [
      {
        field: 'index_name',
        value: null,
      },
      {
        field: 'table_name',
        value: null,
      },
    ],
  },
  {
    key: '添加主键',
    value: [
      {
        field: 'table_name',
        value: null,
      },
      {
        field: 'column_name',
        value: null,
      },
    ],
  },
  {
    key: '移除主键',
    value: [
      {
        field: 'table_name',
        value: null,
      },
    ],
  },
  {
    key: '添加外键约束',
    value: [
      {
        field: 'table_name',
        value: null,
      },
      {
        field: 'constraint_name',
        value: null,
      },
      {
        field: 'column_name',
        value: null,
      },
      {
        field: 'referenced_table_name',
        value: null,
      },
      {
        field: 'referenced_column_name',
        value: null,
      },
    ],
  },
  {
    key: '移除外键约束',
    value: [
      {
        field: 'table_name',
        value: null,
      },
      {
        field: 'constraint_name',
        value: null,
      },
    ],
  },
];
